@@ -3,8 +3,8 @@ with open('ex-3.02.py') as source:
 
 count  = 2
 blklen = 3
-stride = 4
-newtype = dtype.Create_vector(count, blklen, stride)
+stride = 4 * dtype.extent
+newtype = dtype.Create_hvector(count, blklen, stride)
 
 assert newtype.size == dtype.size * count * blklen
 
